slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPQArnoldiSetLocking

Choose between locking and non-locking variants of the Q-Arnoldi method.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPQArnoldiSetLocking(PEP pep,PetscBool lock)

Logically Collective on pep

### Input Parameters

| pep | - the eigenproblem solver context
| lock | - true if the locking variant must be selected

### Options Database Key

| -pep_qarnoldi_locking | - Sets the locking flag

### Notes

The default is to lock converged eigenpairs when the method restarts. This behaviour can be changed so that all directions are kept in the working subspace even if already converged to working accuracy (the non-locking variant).

### See Also

PEPQArnoldiGetLocking()

### Level

advanced

### Location

src/pep/impls/krylov/qarnoldi/qarnoldi.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages